[java-opensaml2 COMMIT] in /branches/REL_2: doc/RELEASE-NOTES.txt src/main/java/org/opensaml/saml1/core/StatusCode.java

noreply at shibboleth.net noreply at shibboleth.net
Thu Feb 20 19:58:18 EST 2014


Author: putmanb
Date: Thu Feb 20 19:58:18 2014
New Revision: 1663

URL: http://svn.shibboleth.net/view/java-opensaml2?rev=1663&view=rev
Log:
JOST-223: Misspelled error constant in SAML 1 StatusCode interface.
Marking in release notes for now as v2.6.2, pending discussion of whether we really want to rev the minor version over this "API addition".

Modified:
    branches/REL_2/doc/RELEASE-NOTES.txt
    branches/REL_2/src/main/java/org/opensaml/saml1/core/StatusCode.java

Modified: branches/REL_2/doc/RELEASE-NOTES.txt
URL: http://svn.shibboleth.net/view/java-opensaml2/branches/REL_2/doc/RELEASE-NOTES.txt?rev=1663&r1=1662&r2=1663&view=diff
==============================================================================
--- branches/REL_2/doc/RELEASE-NOTES.txt (original)
+++ branches/REL_2/doc/RELEASE-NOTES.txt Thu Feb 20 19:58:18 2014
@@ -1,3 +1,7 @@
+Changes in Release 2.6.2
+=============================================
+[JOST-223] - Misspelled error constant in SAML 1 StatusCode interface
+
 Changes in Release 2.6.1
 =============================================
 [JOST-210] - AbstractSAMLObject should not override equals but not hashCode

Modified: branches/REL_2/src/main/java/org/opensaml/saml1/core/StatusCode.java
URL: http://svn.shibboleth.net/view/java-opensaml2/branches/REL_2/src/main/java/org/opensaml/saml1/core/StatusCode.java?rev=1663&r1=1662&r2=1663&view=diff
==============================================================================
--- branches/REL_2/src/main/java/org/opensaml/saml1/core/StatusCode.java (original)
+++ branches/REL_2/src/main/java/org/opensaml/saml1/core/StatusCode.java Thu Feb 20 19:58:18 2014
@@ -62,11 +62,17 @@
     public static final QName REQUEST_VERSION_TOO_LOW = new QName(SAMLConstants.SAML10P_NS, "RequestVersionTooLow",
             SAMLConstants.SAML1P_PREFIX);
 
-    /** RequestVersionDepricated status value. */
-    public static final QName REQUEST_VERSION_DEPRICATED = new QName(SAMLConstants.SAML10P_NS,
-            "RequestVersionDepricated", SAMLConstants.SAML1P_PREFIX);
+    /** RequestVersionDeprecated status value. */
+    public static final QName REQUEST_VERSION_DEPRECATED = new QName(SAMLConstants.SAML10P_NS,
+            "RequestVersionDeprecated", SAMLConstants.SAML1P_PREFIX);
 
-    /** TooManyResponses status value. */
+    /** 
+     * RequestVersionDepricated status value <i>(sic)</i>.
+     * 
+     * @deprecated due to typo, use {@link #REQUEST_VERSION_DEPRECATED} instead.
+     * */
+    public static final QName REQUEST_VERSION_DEPRICATED = REQUEST_VERSION_DEPRECATED;
+    
     public static final QName TOO_MANY_RESPONSES = new QName(SAMLConstants.SAML10P_NS, "TooManyResponses",
             SAMLConstants.SAML1P_PREFIX);
 



More information about the commits mailing list